==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { MultiColumnComboBoxValueChangedEventArgsDescription } from "./MultiColumnComboBoxValueChangedEventArgsDescription";
/**
 * @hidden
 */
var MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata, _super);
    function MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a == null) {
            MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.c(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
    };
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.d = function (a) {
        MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.b(a);
        a.u("MultiColumnComboBoxValueChangedEventArgs", function () { return new MultiColumnComboBoxValueChangedEventArgsDescription(); });
        a.t("MultiColumnComboBoxValueChangedEventArgs", MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
    };
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.$t = markType(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata, 'MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata');
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a = null;
    return MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata;
}(Base));
export { MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { MultiColumnComboBoxValueChangedEventArgsDescription } from "./MultiColumnComboBoxValueChangedEventArgsDescription";
/**
 * @hidden
 */
var MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata, _super);
    function MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a == null) {
            MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.c(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
    };
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.d = function (a) {
        MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.b(a);
        a.aa("MultiColumnComboBoxValueChangedEventArgs", function () { return new MultiColumnComboBoxValueChangedEventArgsDescription(); });
        a.z("MultiColumnComboBoxValueChangedEventArgs", MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a);
    };
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.$t = markType(MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata, 'MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata');
    MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata.a = null;
    return MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata;
}(Base));
export { MultiColumnComboBoxValueChangedEventArgsDescriptionMetadata };
